@@ -2,8 +2,8 @@ import threading
 from typing import *
 
 from cognite.client.data_classes._base import *
-from cognite.client.data_classes.shared import TimestampRange
 from cognite.client.data_classes.labels import Label, LabelFilter
+from cognite.client.data_classes.shared import TimestampRange
 
 
 class AssetAggregate(dict):
@@ -79,7 +79,7 @@ class Asset(CogniteResource):
         aggregates: Union[Dict[str, Any], AggregateResultItem] = None,
         cognite_client=None,
     ):
-        if labels is not None and len(labels) > 0 and not isinstance(labels[0], Label):
+        if labels is not None and len(labels) > 0 and not all(isinstance(l, Label) for l in labels):
             raise TypeError("Asset.labels should be of type List[Label]")
         self.external_id = external_id
         self.name = name
